@@ -6,7 +6,7 @@ test_that("mps_on_date return expected format", {
   skip_on_cran()
   
   xmpon <- mps_on_date("2017-04-30")
-  expect_length(xmpon, 38)
+  expect_length(xmpon, 37)
   expect_type(xmpon, "list")
   expect_true(tibble::is_tibble(xmpon))
   expect_true(nrow(xmpon)==649)
@@ -17,7 +17,7 @@ test_that("mps_on_date return expected format", {
   expect_true(tibble::is_tibble(xmpon2))
   expect_true(nrow(xmpon2)==1730)
   
-  xmpon3 <- mps_on_date(date2="1990-04-30", date1="2015-05-10")
+  xmpon3 <- mps_on_date(date2="1990-04-30", date1="2015-05-10", tidy=FALSE)
   expect_length(xmpon3, 21)
   expect_type(xmpon3, "list")
   expect_true(tibble::is_tibble(xmpon3))
